==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/ja.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ja', {
	acccessKey: 'アクセスキー',
	advanced: '高度な設定',
	advisoryContentType: 'Content Type属性',
	advisoryTitle: 'Title属性',
	anchor: {
		toolbar: 'アンカー挿入/編集',
		menu: 'アンカーの編集',
		title: 'アンカーのプロパティ',
		name: 'アンカー名',
		errorName: 'アンカー名を入力してください。',
		remove: 'アンカーを削除'
	},
	anchorId: 'エレメントID',
	anchorName: 'アンカー名',
	charset: 'リンク先のcharset',
	cssClasses: 'スタイルシートクラス',
	emailAddress: 'E-Mail アドレス',
	emailBody: '本文',
	emailSubject: '件名',
	id: 'Id',
	info: 'ハイパーリンク情報',
	langCode: '言語コード',
	langDir: '文字表記の方向',
	langDirLTR: '左から右 (LTR)',
	langDirRTL: '右から左 (RTL)',
	menu: 'リンクを編集',
	name: 'Name属性',
	noAnchors: '(このドキュメント内にアンカーはありません)',
	noEmail: 'メールアドレスを入力してください。',
	noUrl: 'リンクURLを入力してください。',
	other: '<その他の>',
	popupDependent: '開いたウィンドウに連動して閉じる (Netscape)',
	popupFeatures: 'ポップアップウィンドウ特徴',
	popupFullScreen: '全画面モード(IE)',
	popupLeft: '左端からの座標で指定',
	popupLocationBar: 'ロケーションバー',
	popupMenuBar: 'メニューバー',
	popupResizable: 'サイズ可変',
	popupScrollBars: 'スクロールバー',
	popupStatusBar: 'ステータスバー',
	popupToolbar: 'ツールバー',
	popupTop: '上端からの座標で指定',
	rel: '関連リンク',
	selectAnchor: 'アンカーを選択',
	styles: 'スタイルシート',
	tabIndex: 'タブインデックス',
	target: 'ターゲット',
	targetFrame: '<フレーム>',
	targetFrameName: 'ターゲットのフレーム名',
	targetPopup: '<ポップアップウィンドウ>',
	targetPopupName: 'ポップアップウィンドウ名',
	title: 'ハイパーリンク',
	toAnchor: 'ページ内のアンカー',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toolbar: 'リンク挿入/編集',
	type: 'リンクタイプ',
	unlink: 'リンクを削除',
	upload: 'アップロード'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/ja.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ja', {
	acccessKey: 'アクセスキー',
	advanced: '高度な設定',
	advisoryContentType: 'Content Type属性',
	advisoryTitle: 'Title属性',
	anchor: {
		toolbar: 'アンカー挿入/編集',
		menu: 'アンカーの編集',
		title: 'アンカーのプロパティ',
		name: 'アンカー名',
		errorName: 'アンカー名を入力してください。',
		remove: 'アンカーを削除'
	},
	anchorId: 'エレメントID',
	anchorName: 'アンカー名',
	charset: 'リンク先のcharset',
	cssClasses: 'スタイルシートクラス',
	download: '強制的にダウンロード',
	displayText: '表示文字',
	emailAddress: 'E-Mail アドレス',
	emailBody: '本文',
	emailSubject: '件名',
	id: 'Id',
	info: 'ハイパーリンク情報',
	langCode: '言語コード',
	langDir: '文字表記の方向',
	langDirLTR: '左から右 (LTR)',
	langDirRTL: '右から左 (RTL)',
	menu: 'リンクを編集',
	name: 'Name属性',
	noAnchors: '(このドキュメント内にアンカーはありません)',
	noEmail: 'メールアドレスを入力してください。',
	noUrl: 'リンクURLを入力してください。',
	noTel: 'Please type the phone number', // MISSING
	other: '<その他の>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: '開いたウィンドウに連動して閉じる (Netscape)',
	popupFeatures: 'ポップアップウィンドウ特徴',
	popupFullScreen: '全画面モード(IE)',
	popupLeft: '左端からの座標で指定',
	popupLocationBar: 'ロケーションバー',
	popupMenuBar: 'メニューバー',
	popupResizable: 'サイズ可変',
	popupScrollBars: 'スクロールバー',
	popupStatusBar: 'ステータスバー',
	popupToolbar: 'ツールバー',
	popupTop: '上端からの座標で指定',
	rel: '関連リンク',
	selectAnchor: 'アンカーを選択',
	styles: 'スタイルシート',
	tabIndex: 'タブインデックス',
	target: 'ターゲット',
	targetFrame: '<フレーム>',
	targetFrameName: 'ターゲットのフレーム名',
	targetPopup: '<ポップアップウィンドウ>',
	targetPopupName: 'ポップアップウィンドウ名',
	title: 'ハイパーリンク',
	toAnchor: 'ページ内のアンカー',
	toEmail: 'E-Mail',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'リンク挿入/編集',
	type: 'リンクタイプ',
	unlink: 'リンクを削除',
	upload: 'アップロード'
} );
